@@ -6,7 +6,7 @@ class CategorySerializer(ModelSerializer):
 
     class Meta:
         model = Category
-        fields = ('id', 'category')
+        fields = ('id', 'category', 'category_label')
 
 class VMWorkLogSerializer(ModelSerializer):
     
